==> ecomero-businesscentral-1.0.24.zip: Model/Config/Source/CompanyList.php <==
<?php declare(strict_types=1);
/**
 *
 *           a88888P8
 *          d8'
 * .d8888b. 88        .d8888b. 88d8b.d8b. .d8888b. .dd888b. .d8888b.
 * 88ooood8 88        88'  `88 88'`88'`88 88ooood8 88'    ` 88'  `88
 * 88.  ... Y8.       88.  .88 88  88  88 88.  ... 88       88.  .88
 * `8888P'   Y88888P8 `88888P' dP  dP  dP `8888P'  dP       `88888P'
 *
 *           Copyright © eComero Management AB, All rights reserved.
 *
 */
namespace Ecomero\BusinessCentral\Model\Config\Source;

use Ecomero\BusinessCentral\Helper\Settings;
use Ecomero\BusinessCentral\Model\BusinessCentral;
use Psr\Log\LoggerInterface;

class CompanyList implements \Magento\Framework\Option\ArrayInterface
{
    protected $businessCentral;
    protected $settings;
    private $logger;

    public function __construct(
        BusinessCentral $businessCentral,
        Settings $settings,
        LoggerInterface $logger
    ) {
        $this->businessCentral = $businessCentral;
        $this->settings = $settings;
        $this->logger = $logger;
    }

    public function toOptionArray() : array
    {
        $ret = [];
        $ret[] = [
            'value' =>  $this->settings->getAPICompanyName(),
            'label' => 'NO CONNECTION WITH BUSINESS CENTRAL'
        ];
        try {
            $arr = [];
            $companies = $this->businessCentral->getCompanies();
            foreach ($companies->value as $company) {
                $arr[ $company->name ] = $company->name;
            }

            $ret = [];
            foreach ($arr as $key => $value) {
                $ret[] = [
                    'value' => $key,
                    'label' => $key
                ];
            }
        } catch (\Zend\Http\Exception\RuntimeException $exception) {
            $this->logger->debug($exception->getMessage());
        } catch (\Magento\Framework\Exception\LocalizedException $exception) {
            $this->logger->debug($exception->getMessage());
        } catch (\RuntimeException $exception) {
            $this->logger->debug($exception->getMessage());
        }
        return $ret;
    }
}

==> ecomero-businesscentral-1.0.40.zip: Model/Config/Source/CompanyList.php <==
<?php declare(strict_types=1);
/**
 *
 *           a88888P8
 *          d8'
 * .d8888b. 88        .d8888b. 88d8b.d8b. .d8888b. .dd888b. .d8888b.
 * 88ooood8 88        88'  `88 88'`88'`88 88ooood8 88'    ` 88'  `88
 * 88.  ... Y8.       88.  .88 88  88  88 88.  ... 88       88.  .88
 * `8888P'   Y88888P8 `88888P' dP  dP  dP `8888P'  dP       `88888P'
 *
 *           Copyright © eComero Management AB, All rights reserved.
 *
 */
namespace Ecomero\BusinessCentral\Model\Config\Source;

use Ecomero\BusinessCentral\Helper\Settings;
use Ecomero\BusinessCentral\Model\BusinessCentralAPI;
use Psr\Log\LoggerInterface;

class CompanyList implements \Magento\Framework\Option\ArrayInterface
{
    protected $businessCentral;
    protected $settings;
    private $logger;

    public function __construct(
        BusinessCentralAPI $businessCentral,
        Settings $settings,
        LoggerInterface $logger
    ) {
        $this->businessCentral = $businessCentral;
        $this->settings = $settings;
        $this->logger = $logger;
    }

    public function toOptionArray() : array
    {
        $ret = [];
        $ret[] = [
            'value' =>  $this->settings->getAPICompanyName(),
            'label' => 'NO CONNECTION WITH BUSINESS CENTRAL'
        ];
        try {
            $arr = [];
            $companies = $this->businessCentral->getCompanies();
            foreach ($companies->value as $company) {
                $arr[ $company->name ] = $company->name;
            }

            $ret = [];
            foreach ($arr as $key => $value) {
                $ret[] = [
                    'value' => $key,
                    'label' => $key
                ];
            }
        } catch (\Zend\Http\Exception\RuntimeException $exception) {
            $this->logger->debug($exception->getMessage());
        } catch (\Magento\Framework\Exception\LocalizedException $exception) {
            $this->logger->debug($exception->getMessage());
        } catch (\RuntimeException $exception) {
            $this->logger->debug($exception->getMessage());
        }
        return $ret;
    }
}
